@@ -157,7 +157,7 @@ groups <- list(Regions=Regions, Pop=PopDist,
                )
 
 group_paths <- lapply(groups, FUN= function(g) g[zenpath(length(g), method = "front.loaded")] )
-x <- group(de_elect, indices=group_paths)
+x <- groupData(de_elect, indices=group_paths)
 
 zenplot(x, pch = ".", cex=0.7, col = "grey10")
 
@@ -258,9 +258,9 @@ zenplot(earthquakes[,zenpath(ncol(earthquakes))],
           },
         plot2d=function(zargs, ...) {
           r <- extract_2d(zargs) # extract arguments for 2d
-          x <- r$x
+          x <- as.matrix(r$x)
           xlim <- r$xlim
-          y <- r$y
+          y <- as.matrix(r$y)
           ylim <- r$ylim
           qqtest(y, dataTest=x,
                  xlim=xlim, ylim=ylim,
